import { CssBaseline } from '@material-ui/core';
import React, { useEffect, useState } from 'react';
import { useSelector } from 'react-redux';
import { BrowserRouter as Router, Route, Switch } from 'react-router-dom';
import TokenLoader from './components/App/TokenLoader';
import CityFinder from './components/common/CityFinder';
import CustomSnackbar from './components/common/CustomSnackbar';
import { Client, Clients, Home, Invoice, Invoices, Line, Login, NotFound, PasswordRecovery, Print, Profile, Register } from './pages';
import { AppState } from './redux/reducers';
import { UiState } from './redux/reducers/ui';

function App() {
  const { title }: UiState = useSelector<AppState, any>(state => state.ui);
  const [tokenLoaded, setTokenLoaded] = useState<boolean>(false);

  // set page title
  useEffect(() => {
    document.title = title + " - Easybill";
  }, [title])

  return (
    <Router basename={process.env.REACT_APP_HOMEPAGE}>
      <CssBaseline>
        <CustomSnackbar />
        <TokenLoader setTokenLoaded={setTokenLoaded} />
        {tokenLoaded &&
          <Switch>
            <Route exact path="/" component={Home} />
            <Route exact path="/login" component={Login} />
            <Route exact path="/register" component={Register} />
            <Route exact path="/restore/:jwt" component={PasswordRecovery} />
            <Route exact path="/invoices" component={Invoices} />
            <Route exact path="/invoices/:number" component={Invoice} />
            <Route exact path="/lines/:id" component={Line} />
            <Route exact path="/clients" component={Clients} />
            <Route exact path="/clients/:nif" component={Client} />
            <Route exact path="/profile" component={Profile} />
            <Route exact path="/print/:number" component={Print} />
            <Route exact path="/cities" component={CityFinder} />
            <Route component={NotFound} />
          </Switch>
        }
      </CssBaseline>
    </Router>
  );
}

export default App;
