import { TOKEN_PREFIX } from "../constants/common";
import { checkConnection } from "../lib/network";

export const login = async (email: string, password: string): Promise<any> => {
  checkConnection();
  const response = await fetch(process.env.REACT_APP_API_URL + 'auth/login', {
    method: 'POST',
    headers: {
      'Content-Type': 'application/json',
    },
    body: JSON.stringify({ email, password })
  });
  if (response.status === 200) {
    const token = await response.text();
    localStorage.setItem('jwtToken', token);
    return token;
  } else {
    const error = await response.json();
    throw error;
  }
}

export const register = async (userData: any): Promise<string> => {
  checkConnection();
  const response = await fetch(process.env.REACT_APP_API_URL + 'auth/register', {
    method: 'POST',
    headers: {
      'Content-Type': 'application/json',
    },
    body: JSON.stringify(userData)
  });
  if (response.status === 201) {
    const token = await response.text();
    localStorage.setItem('jwtToken', token);
    return token;
  }
  const error = await response.json();
  throw error;
}

export const logout = async (): Promise<boolean> => {
  checkConnection();
  const token = localStorage.getItem('jwtToken') || '';
  const response = await fetch(process.env.REACT_APP_API_URL + 'auth/logout', {
    method: 'POST',
    headers: {
      'Authorization': `${TOKEN_PREFIX} ${token}`,
      'Content-Type': 'application/json',
    },
  });
  localStorage.removeItem('jwtToken');
  return await response.json();
}

export const sendRecoveryEmail = async (email: string): Promise<string> => {
  checkConnection();
  const response = await fetch(process.env.REACT_APP_API_URL + 'auth/sendjwt', {
    method: 'POST',
    headers: {
      'Content-Type': 'application/json',
    },
    body: JSON.stringify({ email })
  });
  if (response.status === 200) {
    return await response.text();
  }
  const error = await response.json();
  throw error;
}

export const sendRestorePassword = async (token: string, data: any): Promise<string> => {
  checkConnection();
  const response = await fetch(process.env.REACT_APP_API_URL + 'auth/restore', {
    method: 'PUT',
    headers: {
      'Authorization': `${TOKEN_PREFIX} ${token}`,
      'Content-Type': 'application/json',
    },
    body: JSON.stringify(data)
  });
  if (response.status === 201) {
    return await response.text();
  }
  const error = await response.json();
  throw error;
}
