import { AuthError } from "../classes/AuthError";
import { TOKEN_PREFIX } from "../constants/common";
import { checkConnection } from "../lib/network";

const url = process.env.REACT_APP_API_URL;
const token_prefix = TOKEN_PREFIX;

const getToken = () => localStorage.getItem('jwtToken') || '';

const checkResponse = async (response: Response, code: number, type = 'json') => {
  if (response.status === code) {
    return type === 'json'
      ? await response.json()
      : await response.text();
  } else {
    if (response.status === 401) throw new AuthError();
    const error = await response.json();
    throw error;
  }
}

export const getItemList = async (endpoint: string): Promise<any> => {
  checkConnection();
  const token = getToken();
  const response = await fetch(url + endpoint, {
    headers: {
      'Authorization': `${token_prefix} ${token}`,
      'Content-Type': 'application/json',
    }
  });
  return checkResponse(response, 200);
}

export const getItem = async (endpoint: string, id: string): Promise<any> => {
  checkConnection();
  const token = getToken();
  const response = await fetch(`${url}${endpoint}/${id}`, {
    headers: {
      'Authorization': `${token_prefix} ${token}`,
      'Content-Type': 'application/json',
    }
  });
  return checkResponse(response, 200);
}

export const addItem = async (endpoint: string, data: any): Promise<any> => {
  checkConnection();
  const token = getToken();
  const response = await fetch(url + endpoint, {
    method: "POST",
    headers: {
      'Authorization': `${token_prefix} ${token}`,
      'Content-Type': 'application/json',
    },
    body: JSON.stringify(data)
  });
  return checkResponse(response, 201);
}

export const updateItem = async (endpoint: string, data: any): Promise<any> => {
  checkConnection();
  const token = getToken();
  const response = await fetch(url + endpoint + '/' + data._id, {
    method: "PUT",
    headers: {
      'Authorization': `${token_prefix} ${token}`,
      'Content-Type': 'application/json',
    },
    body: JSON.stringify(data)
  });
  return checkResponse(response, 202);
}

export const deleteItem = async (endpoint: string, id: string): Promise<any> => {
  checkConnection();
  const token = getToken();
  const response = await fetch(url + endpoint + '/' + id, {
    method: "DELETE",
    headers: {
      'Authorization': `${token_prefix} ${token}`,
      'Content-Type': 'application/json',
    },
  });
  return checkResponse(response, 204, 'text');
}
