import { AuthError } from "../classes/AuthError";
import { TOKEN_PREFIX } from "../constants/common";
import { checkConnection } from "../lib/network";

const url = process.env.REACT_APP_API_URL;
const token_prefix = TOKEN_PREFIX;

export const getCurrentUser = async (): Promise<any> => {
  checkConnection();
  const token = localStorage.getItem('jwtToken') || '';
  const response = await fetch(url + 'users', {
    headers: {
      'Authorization': `${token_prefix} ${token}`,
      'Content-Type': 'application/json',
    }
  });
  if (response.status === 200) {
    return await response.json();
  } else {
    if (response.status === 401) throw new AuthError();
    const error = await response.json();
    throw error;
  }
}


export const updateUser = async (userData: any): Promise<any> => {
  checkConnection();
  const token = localStorage.getItem('jwtToken') || '';
  const response = await fetch(url + 'users/', {
    method: "PUT",
    headers: {
      'Authorization': `${token_prefix} ${token}`,
      'Content-Type': 'application/json',
    },
    body: JSON.stringify(userData)
  });
  if (response.status === 202) {
    return await response.json();
  } else {
    if (response.status === 401) throw new AuthError();
    const error = await response.json();
    throw error;
  }
}

