import React, { useEffect } from 'react';
import { useDispatch, useSelector } from 'react-redux';
import { useHistory } from 'react-router-dom';
import api from '../../api';
import actions from '../../redux/actions';
import { AppState } from '../../redux/reducers';
import { UiState } from '../../redux/reducers/ui';
import CustomBackdrop from '../common/CustomBackdrop';

type Props = {
  setTokenLoaded: Function;
}

const TokenLoader = ({ setTokenLoaded }: Props) => {
  const dispatch = useDispatch();
  const history = useHistory();
  const { isLoading }: UiState = useSelector<AppState, any>(state => state.ui);

  // if token set, set authenticaded and get user
  useEffect(() => {
    const token = localStorage.getItem('jwtToken');
    if (token) {
      dispatch(actions.setLoading(true));
      dispatch(actions.login(token));
      api.getCurrentUser()
        .then(user => {
          dispatch(actions.setCurrentUser(user));
          history.push('/invoices');
        })
        .catch(error => console.log(error))
        .finally(() => {
          setTokenLoaded(true);
          dispatch(actions.setLoading(false));
        })
    } else
      setTokenLoaded(true);
    // eslint-disable-next-line
  }, [dispatch, setTokenLoaded]);

  return (
    <CustomBackdrop open={isLoading} />
  )
}

export default TokenLoader;