import { FormControl, Grid, InputAdornment, InputLabel, MenuItem, Select, TextField } from '@material-ui/core';
import { makeStyles } from '@material-ui/core/styles';
import { Search } from '@material-ui/icons';
import React, { ChangeEvent, useEffect, useState } from 'react';
import { searchNormalized } from '../../lib/filters';

const CITIES_ALL = 0;

type Props = {
  list: any[];
  setFiltered: Function;
}

const useStyles = makeStyles((theme) => ({
  root: {
    marginTop: theme.spacing(2)
  }
}));

const getClientsCities = (clients: any[]): string[] => {
  const cities = clients.map(client => client.city)
  const output: string[] = [];
  cities.forEach(city => {
    if (!output.includes(city)) output.push(city)
  });
  return output.sort();
}

const ClientsListFilter = ({ list, setFiltered }: Props) => {
  const classes = useStyles();
  const [search, setSearch] = useState<string>("");
  const [city, setCity] = useState<string | number>(CITIES_ALL);

  const handleSearch = (e: ChangeEvent<HTMLInputElement>) => {
    setSearch(e.target.value);
  }

  const handleCity = (e: ChangeEvent<any>) => {
    setCity(e.target.value);
  }

  useEffect(() => {
    setFiltered(
      list
        .filter(client => search === ""
          ? true
          : (searchNormalized(client.name, search)) || searchNormalized(client.surnames, search) || searchNormalized(client.commercialName, search))
        .filter(client => city === CITIES_ALL
          || city === client.city
        )
    );
  }, [list, setFiltered, search, city]);

  return (
    <Grid container className={classes.root} spacing={3}>

      <Grid item xs={6}>
        <TextField
          InputProps={{
            startAdornment: <InputAdornment position="start">
              <Search />
            </InputAdornment>
          }}
          label="Nom"
          fullWidth
          value={search}
          onChange={handleSearch}
        />

      </Grid>

      <Grid item xs={6}>
        <FormControl fullWidth>
          <InputLabel id="demo-simple-select-outlined-label" shrink>Municipi</InputLabel>
          <Select
            labelId="demo-simple-select-outlined-label"
            id="city"
            fullWidth
            value={city}
            onChange={handleCity}
            label="Estat"
          >
            <MenuItem key={CITIES_ALL} value={CITIES_ALL}>Tots</MenuItem>
            {getClientsCities(list).map(city =>
              <MenuItem key={city} value={city}>{city}</MenuItem>
            )}
          </Select>
        </FormControl>
      </Grid>

    </Grid>
  )
}

export default ClientsListFilter
