import { Box, Button, Grid } from '@material-ui/core';
import { makeStyles } from '@material-ui/core/styles';
import { ArrowBackIos, Clear, DeleteForever, Send } from '@material-ui/icons';
import PrintIcon from '@material-ui/icons/Print';
import SaveIcon from '@material-ui/icons/Save';
import React from 'react';
import { useSelector } from 'react-redux';
import { AppState } from '../../redux/reducers';
import { UiState } from '../../redux/reducers/ui';

type Props = {
  data: any;
  newInvoice: boolean;
  emitInvoice: (e: any) => void;
  cancelInvoice: (e: any) => void;
  printInvoice: (e: any) => void;
  cancel: (e: any) => void;
  deleteInvoice: (e: any) => void;
}

const useStyles = makeStyles((theme) => ({
  spacer: {
    width: '100%',
    padding: theme.spacing(1),
  }
}));

const InvoiceFormButtons = ({ data, newInvoice, emitInvoice, cancelInvoice, printInvoice, cancel, deleteInvoice }: Props) => {
  const classes = useStyles();
  const { isSaving, isDeleting, isEmitting, isCancelling }: UiState = useSelector<AppState, any>(state => state.ui);

  return (
    <Grid container spacing={3}>
      {!newInvoice &&
        <>
          <Box className={classes.spacer} />
          <Grid container spacing={3}>
            <Grid item xs={4}>
              <Button
                type="button"
                fullWidth
                variant="outlined"
                color="primary"
                startIcon={<Send />}
                onClick={emitInvoice}
                disabled={data.emitted || data.cancelled}
              >
                {isEmitting ? "Emetent" : "Emet"}
              </Button>
            </Grid>
            <Grid item xs={4}>
              <Button
                type="button"
                fullWidth
                variant="outlined"
                color="secondary"
                startIcon={<Clear />}
                onClick={cancelInvoice}
                disabled={data.cancelled}
              >
                {isCancelling ? "Anul·lant" : "Anul·la"}
              </Button>
            </Grid>
            <Grid item xs={4}>
              <Button
                type="button"
                fullWidth
                variant="outlined"
                color="primary"
                startIcon={<PrintIcon />}
                onClick={printInvoice}
              >
                Imprimeix
          </Button>
            </Grid>
          </Grid>
        </>
      }
      <>
        <Box className={classes.spacer} />
        <Grid container spacing={3}>
          <Grid item xs={newInvoice ? 6 : 4}>
            <Button
              type="submit"
              fullWidth
              variant="contained"
              color="primary"
              startIcon={<SaveIcon />}
              disabled={data.cancelled}
            >
              {isSaving ? "Desant" : "Desa"}
            </Button>
          </Grid>
          <Grid item xs={newInvoice ? 6 : 4}>
            <Button
              type="button"
              fullWidth
              variant="contained"
              startIcon={<ArrowBackIos />}
              onClick={cancel}
            >
              Cancel·la
          </Button>
          </Grid>
          {!newInvoice &&
            <Grid item xs={4}>
              <Button
                type="button"
                fullWidth
                variant="contained"
                color="secondary"
                startIcon={<DeleteForever />}
                onClick={deleteInvoice}
                disabled={data.emitted || data.cancelled}
              >
                {isDeleting ? "Eliminant" : "Elimina"}
              </Button>
            </Grid>
          }
        </Grid>
      </>
    </Grid>
  )
}

export default InvoiceFormButtons
