import { Hidden, Paper, Table, TableBody, TableCell, TableContainer, TableHead, TableRow } from '@material-ui/core';
import EditIcon from '@material-ui/icons/Edit';
import PrintIcon from '@material-ui/icons/Print';
import React from 'react';
import { useHistory } from 'react-router-dom';
import { sortByNumber } from '../../lib/invoices';
import InvoicesListItem from './InvoicesListItem';

type Props = {
  invoices: any[];
}

const InvoicesList = ({ invoices }: Props) => {
  const history = useHistory();

  const editInvoice = (invoice: any) => {
    history.push('/invoices/' + invoice.number);
  }

  const printInvoice = (invoice: any) => {
    history.push('/print/' + invoice.number);
  }

  return (
    <TableContainer component={Paper}>
      <Table>
        <Hidden xsDown>
          <TableHead>
            <TableRow>
              <TableCell>Número</TableCell>
              <TableCell>Concepte</TableCell>
              <TableCell>Import</TableCell>
              <TableCell>IVA</TableCell>
              <TableCell>Retenció</TableCell>
              <TableCell>Total</TableCell>
              <TableCell><EditIcon fontSize="small" /></TableCell>
              <TableCell><PrintIcon fontSize="small" /></TableCell>
            </TableRow>
          </TableHead>
        </Hidden>
        <TableBody>
          {sortByNumber(invoices).map(invoice =>
            <InvoicesListItem
              key={invoice.number}
              invoice={invoice}
              editInvoice={editInvoice}
              printInvoice={printInvoice}
            />
          )}
        </TableBody>
      </Table>
    </TableContainer>
  )
}

export default InvoicesList
