import { Button, Hidden, TableCell, TableRow } from '@material-ui/core';
import { makeStyles } from '@material-ui/core/styles';
import EditIcon from '@material-ui/icons/Edit';
import PrintIcon from '@material-ui/icons/Print';
import React from 'react';

type Props = {
  invoice: any;
  editInvoice: (invoice: any) => void;
  printInvoice: (invoice: any) => void;
}

const useStyles = makeStyles((theme) => ({
  active: {
    color: 'blue'
  },
  emitted: {
    color: 'green'
  },
  cancelled: {
    color: 'red'
  },
  alignRight: {
    textAlign: "right",
  }
}));

const getRetention = (invoice: any) => {
  return (invoice.ret / 100 * invoice.amount);
}

const getTotal = (invoice: any) => {
  return invoice.amount + invoice.vat - getRetention(invoice);
}

const InvoicesListItem = ({ invoice, editInvoice, printInvoice }: Props) => {
  const classes = useStyles();

  const getInvoiceClass = () => {
    if (invoice.cancelled) return classes.cancelled;
    if (invoice.emitted) return classes.emitted;
    return classes.active;
  }

  const handleTouchInvoice = () => {
    editInvoice(invoice);
  }

  return (
    <TableRow>
      <TableCell
        onTouchEnd={handleTouchInvoice}
        className={getInvoiceClass()}
      >
        {invoice.number}
      </TableCell>
      <TableCell
        onTouchEnd={handleTouchInvoice}
      >
        {invoice.name}
      </TableCell>
      <TableCell
        onTouchEnd={handleTouchInvoice}
        className={classes.alignRight}
      >
        {invoice.amount.toFixed(2)}€
      </TableCell>
      <Hidden xsDown>
        <TableCell
          className={classes.alignRight}
        >
          {invoice.vat.toFixed(2)}€
        </TableCell>
        <TableCell
          className={classes.alignRight}
        >
          {getRetention(invoice).toFixed(2)}€
        </TableCell>
        <TableCell
          className={classes.alignRight}
        >
          {getTotal(invoice).toFixed(2)}€
        </TableCell>
        <TableCell size="small">
          <Button
            color="primary"
            size="small"
            startIcon={<EditIcon />}
            onClick={e => editInvoice(invoice)}
          >
            Edita
        </Button>
        </TableCell>
        <TableCell size="small">
          <Button
            color="primary"
            size="small"
            startIcon={<PrintIcon />}
            onClick={e => printInvoice(invoice)}
          >
            Imprimeix
        </Button>
        </TableCell>
      </Hidden>
    </TableRow>
  )
}

export default InvoicesListItem
