import { Table, TableBody, TableCell, TableContainer, TableHead, TableRow } from '@material-ui/core';
import React, { useEffect } from 'react';
import { useDispatch, useSelector } from 'react-redux';
import api from '../../api';
import { NetworkError } from '../../classes/NetworkError';
import actions from '../../redux/actions';
import { AppState } from '../../redux/reducers';
import { AuthState } from '../../redux/reducers/auth';
import { InvoicesState } from '../../redux/reducers/invoices';
import { LinesState } from '../../redux/reducers/lines';
import LinesListItem from './LinesListItem';

const LinesList = () => {
  const dispatch = useDispatch();
  const { token }: AuthState = useSelector<AppState, any>(state => state.auth);
  const { lines }: LinesState = useSelector<AppState, any>(state => state.lines);
  const { invoice }: InvoicesState = useSelector<AppState, any>(state => state.invoices);

  useEffect(() => {
    if (invoice._id) {
      dispatch(actions.setLoading(true));
      api.getLines(invoice._id)
        .then(lines => dispatch(actions.setLines(lines)))
        .catch(error => {
          if (error instanceof NetworkError)
            dispatch(actions.setSnackbar("No teniu connexió a Internet", "error"));
        })
        .finally(() => dispatch(actions.setLoading(false)));
    } else {
      dispatch(actions.setLines([]));
    }
  }, [token, invoice._id, dispatch]);

  return (
    <TableContainer>
      <Table size="small">
        <TableHead>
          <TableRow>
            <TableCell>Concepte</TableCell>
            <TableCell>Subtotal</TableCell>
            <TableCell>IVA</TableCell>
            <TableCell></TableCell>
          </TableRow>
        </TableHead>
        <TableBody>
          {invoice && lines.map((line: any) =>
            <LinesListItem key={line._id} line={line} invoice={invoice} />
          )}
        </TableBody>
      </Table>
    </TableContainer>
  )
}

export default LinesList
