import { Avatar, Button, Container, TextField, Typography } from '@material-ui/core';
import { makeStyles } from '@material-ui/core/styles';
import VpnKeyIcon from '@material-ui/icons/VpnKey';
import React, { FormEvent } from 'react';
import { useSelector } from 'react-redux';
import { MATCH_PASSWORDS, PASSWORD_CONFIRMATION_REQUIRED, PASSWORD_LENGTH, PASSWORD_REQUIRED } from '../../constants/errors';
import { getError, hasError } from '../../lib/errors';
import { AppState } from '../../redux/reducers';
import { ErrorsState } from '../../redux/reducers/errors';
import { UiState } from '../../redux/reducers/ui';
import CustomBackdrop from '../common/CustomBackdrop';

type Props = {
  data: any;
  setData: Function;
  submit: (e: FormEvent<HTMLFormElement>) => void;
}

const useStyles = makeStyles((theme) => ({
  paper: {
    marginTop: theme.spacing(8),
    display: 'flex',
    flexDirection: 'column',
    alignItems: 'center',
  },
  avatar: {
    margin: theme.spacing(1),
    backgroundColor: theme.palette.secondary.main,
  },
  form: {
    width: '100%', // Fix IE 11 issue.
    marginTop: theme.spacing(1),
  },
  submit: {
    margin: theme.spacing(3, 0, 2),
  },
}));

const PasswordRecoveryForm = ({ data, setData, submit }: Props) => {
  const classes = useStyles();
  const errors: ErrorsState = useSelector<AppState, any>(state => state.errors);
  const { isSaving }: UiState = useSelector<AppState, any>(state => state.ui);

  return (
    <Container component="main" maxWidth="xs">
      <div className={classes.paper}>
        <Avatar className={classes.avatar}>
          <VpnKeyIcon />
        </Avatar>
        <Typography component="h1" variant="h5">
          Restablir contrasenya
        </Typography>

        <fieldset disabled={isSaving} style={{ border: "none" }}>
          <form onSubmit={submit} className={classes.form}>
            <TextField
              variant="outlined"
              margin="normal"
              required
              fullWidth
              name="password"
              label="Contrasenya"
              type="password"
              id="password"
              autoComplete="current-password"
              error={hasError(errors, PASSWORD_REQUIRED) || hasError(errors, PASSWORD_LENGTH)}
              helperText={getError(errors, PASSWORD_REQUIRED) || getError(errors, PASSWORD_LENGTH)}
              value={data.password}
              onChange={e => setData({ ...data, password: e.target.value })}
            />

            <TextField
              variant="outlined"
              margin="normal"
              required
              fullWidth
              name="password2"
              label="Repeteix contrasenya"
              type="password"
              id="password2"
              error={hasError(errors, PASSWORD_CONFIRMATION_REQUIRED) || hasError(errors, MATCH_PASSWORDS)}
              helperText={getError(errors, PASSWORD_CONFIRMATION_REQUIRED) || getError(errors, MATCH_PASSWORDS)}
              value={data.password2}
              onChange={e => setData({ ...data, password2: e.target.value })}
            />

            <Button
              type="submit"
              fullWidth
              variant="contained"
              color="primary"
              className={classes.submit}
            >
              {isSaving ? "Desant" : "Desa"}
            </Button>

          </form>
        </fieldset>
        <CustomBackdrop open={isSaving} />
      </div>
    </Container>
  )
}

export default PasswordRecoveryForm
