import { Button, Dialog, DialogActions, DialogContent, DialogTitle, Grid, TextField } from '@material-ui/core';
import React, { useEffect, useState } from 'react';

const PASSWORD_TOO_SHORT = "La contrasenya ha de contenir almenys 6 caràcters";
const PASSWORD_NOT_MATCH = "Les contrasenyes no coincideixen";

type Props = {
  open: boolean;
  setOpen: Function;
  changePassword: (password: string, password2: string) => void;
}

const DialogModifyPassword = ({ open, setOpen, changePassword }: Props) => {
  const [password, setPassword] = useState<string>("");
  const [password2, setPassword2] = useState<string>("");
  const [errors, setErrors] = useState<any>({ password: PASSWORD_TOO_SHORT, password2: "" });
  const [pristine, setPristine] = useState<boolean>(true);

  const handleClose = () => {
    setOpen(false);
  };

  const hasErrors = (): boolean => (
    (errors.password && errors.password.length > 0)
    || (errors.password2 && errors.password2.length > 0)
  );

  const submit = () => {
    changePassword(password, password2);
    handleClose();
  }

  // reset values on open dialog
  useEffect(() => {
    if (open) {
      setPassword("");
      setPassword2("");
    }
  }, [open])

  // check for errors
  useEffect(() => {
    const err = ({ password: "", password2: "" });
    if (password.length < 6) err.password = PASSWORD_TOO_SHORT
    if (password !== password2) err.password2 = PASSWORD_NOT_MATCH;
    setErrors(err);
  }, [password, password2]);

  // check if form is pristine
  useEffect(() => {
    setPristine(password === "" && password2 === "")
  }, [password, password2]);

  return (
    <div>
      <Dialog open={open} onClose={handleClose} aria-labelledby="modify-password-title">
        <DialogTitle id="modify-password-title">Modificar la contrasenya</DialogTitle>
        <DialogContent>
          <Grid container spacing={3}>
            <Grid item xs={12}>
              <TextField
                variant="outlined"
                autoFocus
                id="password"
                label="Contrasenya"
                type="password"
                fullWidth
                required
                error={!pristine && errors.password.length > 0}
                helperText={
                  (pristine && "Escriu una contrasenya d'almenys 6 caràcters")
                  || (!pristine && errors.password)
                }
                value={password}
                onChange={e => setPassword(e.target.value)}
              />
            </Grid>
            <Grid item xs={12}>
              <TextField
                variant="outlined"
                id="password2"
                label="Repeteix la contrasenya"
                type="password"
                fullWidth
                required
                error={!pristine && errors.password2.length > 0}
                helperText={errors.password2}
                value={password2}
                onChange={e => setPassword2(e.target.value)}
              />
            </Grid>
          </Grid>
        </DialogContent>
        <DialogActions>
          <Button
            variant="contained"
            onClick={submit}
            color="primary"
            disabled={hasErrors()}
          >
            Modifica
          </Button>
          <Button onClick={handleClose}>
            Cancel·la
          </Button>
        </DialogActions>
      </Dialog>
    </div>
  )
}

export default DialogModifyPassword
