import { TextField } from '@material-ui/core';
import { Autocomplete } from '@material-ui/lab';
import React, { useState } from 'react';
import api from './../../api';

type Props = {
  setData: Function;
}

let timer: any = null;
const debounceTime = 500;

const CityFinder = ({ setData }: Props) => {
  const [option, setOption] = useState<string>("");
  const [cities, setCities] = useState([
    { _id: "0", code: '', city: "" },
  ]);

  const changeTextField = (input: any) => {
    if (timer) clearTimeout(timer);
    timer = setTimeout(() => {
      setOption(input);
      getCities(input);
    }, debounceTime);
  }

  const handleChangeOption = (option: any) => {
    if (option) setData(option);
  }

  const showCity = (city: any) => {
    if (city.code && city.city) return city.code + " " + city.city;
    return "";
  }

  const getCities = async (search: string) => {
    const result = await api.getCities(search);
    if (result) setCities(result);
  }

  return (
    <div>
      <Autocomplete
        options={cities}
        getOptionLabel={(option) => showCity(option)}
        renderInput={(params) =>
          <TextField
            {...params}
            autoFocus
            label="Escull el municipi d'una llista"
            placeholder="Comença a escruire el nom"
            variant="outlined"
            value={option}
          />
        }
        onChange={(event, newValue) => {
          handleChangeOption(newValue);
        }}
        onInputChange={(event, value) => changeTextField(value)}
      />

    </div>
  )
}

export default CityFinder
