import { Button, Dialog, DialogActions, DialogContent, DialogContentText, DialogTitle, Typography } from '@material-ui/core';
import React from 'react';

type color = "primary" | "secondary" | "inherit" | "default" | undefined;

type Props = {
  title?: string;
  lines: string[];
  okLabel: string;
  okColor?: color;
  cancelLabel?: string;
  open: boolean;
  setOpen: Function;
  onOk: () => void;
  onCancel?: () => void;
}

const CustomActionDialog = ({ title, lines, okLabel, cancelLabel = "Cancel·la", okColor = "primary", open, setOpen, onOk, onCancel }: Props) => {

  const handleClose = () => {
    setOpen(false);
  };

  const handleOk = () => {
    onOk();
  }

  const handleCancel = () => {
    if (onCancel) onCancel();
    handleClose();
  }

  return (
    <Dialog
      open={open}
      onClose={handleClose}
      aria-labelledby="delete-dialog-title"
      aria-describedby="delete-dialog-description"
    >
      {title &&
        <DialogTitle id="delete-dialog-title">
          {title}
        </DialogTitle>
      }
      <DialogContent>
        <DialogContentText id="delete-dialog-description">
          {lines.map((line, index) =>
            <Typography key={"custom-dialog-" + index} gutterBottom={index < lines.length}>
              {line}
            </Typography>
          )}
        </DialogContentText>
      </DialogContent>
      <DialogActions>
        <Button variant="contained" onClick={handleOk} color={okColor}>
          {okLabel}
        </Button>
        <Button autoFocus onClick={handleCancel}>
          {cancelLabel}
        </Button>
      </DialogActions>
    </Dialog>
  )
}

export default CustomActionDialog
