import { AppBar, Button, Hidden, IconButton, ListItemIcon, Menu, MenuItem, Toolbar, Typography } from '@material-ui/core';
import { makeStyles } from '@material-ui/core/styles';
import { ArrowBack, Euro, MeetingRoom, People, Person } from '@material-ui/icons';
import MenuIcon from '@material-ui/icons/Menu';
import React, { useState } from 'react';
import { useDispatch, useSelector } from 'react-redux';
import { useHistory } from "react-router-dom";
import actions from '../../redux/actions';
import { AppState } from '../../redux/reducers';
import { UiState } from '../../redux/reducers/ui';

const useStyles = makeStyles((theme) => ({
  root: {
    flexGrow: 1,
  },
  menuButton: {
    marginRight: theme.spacing(2),
  },
  title: {
    flexGrow: 1,
  },
  link: {
    color: "white",
    opacity: 0.7
  },
  activeLink: {
    color: "white",
    opacity: 1
  },
}));

const Header = () => {
  const history = useHistory();
  const dispatch = useDispatch();
  const classes = useStyles();

  const { title }: UiState = useSelector<AppState, any>(state => state.ui);

  const [anchorEl, setAnchorEl] = useState(null);
  const open = Boolean(anchorEl);

  const handleMenu = (event: any) => {
    setAnchorEl(event.currentTarget);
  };

  const handleGoBack = () => {
    history.goBack();
  }

  const handleClose = () => {
    setAnchorEl(null);
  };

  const changePage = (page: string) => {
    handleClose();
    history.push(page);
  }

  const logout = () => {
    handleClose();
    localStorage.removeItem('jwtToken');
    dispatch(actions.logout());
    history.push("/login");
  }

  const getLinkClass = (path: string) => {
    return path === history.location.pathname ? classes.activeLink : classes.link;
  }

  return (
    <div className="print-nav">
      <div className={classes.root}>
        <AppBar position="static">
          <Toolbar>
            <IconButton
              onClick={handleGoBack}
              color="inherit"
            >
              <ArrowBack />
            </IconButton>
            <Typography variant="h6" className={classes.title}>
              {title}
            </Typography>
            <Hidden smUp>
              <IconButton
                aria-label="app bar menu"
                aria-controls="menu-appbar"
                aria-haspopup="true"
                onClick={handleMenu}
                color="inherit"
              >
                <MenuIcon />
              </IconButton>
              <Menu
                id="menu-appbar"
                anchorEl={anchorEl}
                anchorOrigin={{
                  vertical: 'top',
                  horizontal: 'right',
                }}
                keepMounted
                transformOrigin={{
                  vertical: 'top',
                  horizontal: 'right',
                }}
                open={open}
                onClose={handleClose}
              >
                <MenuItem onClick={() => changePage('/invoices')}>
                  <ListItemIcon><Euro fontSize="small" /> </ListItemIcon>
                Factures
              </MenuItem>
                <MenuItem onClick={() => changePage('/clients')}>
                  <ListItemIcon><People /> </ListItemIcon>
                Clients
              </MenuItem>
                <MenuItem onClick={() => changePage('/profile')}>
                  <ListItemIcon><Person fontSize="small" /> </ListItemIcon>
                Dades personals
              </MenuItem>
                <MenuItem onClick={logout}>
                  <ListItemIcon><MeetingRoom fontSize="small" /> </ListItemIcon>
                Sortir
              </MenuItem>
              </Menu>
            </Hidden>
            <Hidden xsDown>
              <Button className={getLinkClass('/invoices')} onClick={() => changePage('/invoices')}>
                Factures
            </Button>
              <Button className={getLinkClass('/clients')} onClick={() => changePage('/clients')}>
                Clients
            </Button>
              <Button className={getLinkClass('/profile')} onClick={() => changePage('/profile')}>
                Dades personals
            </Button>
              <Button className={classes.link} startIcon={<MeetingRoom />} onClick={logout}>
                Sortir
            </Button>
            </Hidden>
          </Toolbar>
        </AppBar>
      </div>
    </div>
  )
}

export default Header
