import { Typography, Grid, Button } from '@material-ui/core';
import React, { ChangeEvent } from 'react';
import { makeStyles } from '@material-ui/core/styles';
import { encodeImageFileAsURL } from '../../lib/images';
import { Clear, Publish } from '@material-ui/icons';

type Props = {
  data: any;
  setData: Function;
}

const useStyles = makeStyles((theme) => ({
  imageContainer: {
    display: 'flex',
    justifyContent: 'center',
  },
  image: {
    maxWidth: 300,
    maxHeight: 300
  },
}));

const ImageLoader = ({ data, setData }: Props) => {
  const classes = useStyles();

  const handleChangePicture = (e: ChangeEvent<HTMLInputElement>) => {
    encodeImageFileAsURL(e, (logo: string) => setData({ ...data, logo }));
  }

  const imageLoaded = data.logo && data.logo !== '';

  return (
    <fieldset>
      <legend><Typography variant="caption" color="textSecondary">Logo</Typography></legend>
      <Grid container>
        <Grid item xs={imageLoaded ? 6 : 12}>
          <label htmlFor="picture-file-button">
            <Button
              component="span"
              size="small"
              color="primary"
              fullWidth
              startIcon={<Publish />}
            >
              {imageLoaded ? "Substituir" : "Carregar"}
            </Button>
          </label>
        </Grid>
        {imageLoaded &&
          <Grid item xs={6}>
            <Button
              component="span"
              size="small"
              fullWidth
              startIcon={<Clear />}
              onClick={() => setData({ ...data, logo: '' })}
            >
              Netejar
        </Button>
          </Grid>
        }
        {
          data.logo &&
          <Grid item xs={12} className={classes.imageContainer}>
            <img src={data.logo} alt="" className={classes.image} />
          </Grid>
        }

      </Grid>
      <input
        accept="image/*"
        id="picture-file-button"
        type='file'
        onChange={handleChangePicture}
        style={{ display: "none" }}
      />
    </fieldset >
  );
}

export default ImageLoader;