import { Container, Grid } from '@material-ui/core';
import Header from '../components/common/Header';
import React, { useEffect, useState } from 'react';
import { useDispatch, useSelector } from 'react-redux';
import { useHistory } from 'react-router-dom';
import api from '../api';
import { AuthError } from '../classes/AuthError';
import { NetworkError } from '../classes/NetworkError';
import AddClientButton from '../components/Clients/AddClientButton';
import ClientsList from '../components/Clients/ClientsList';
import ClientsListFilter from '../components/Clients/ClientsListFilter';
import { sortByNumber } from '../lib/invoices';
import actions from '../redux/actions';
import { AppState } from '../redux/reducers';
import { AuthState } from '../redux/reducers/auth';
import { ClientsState } from '../redux/reducers/clients';

const Clients = () => {
  const dispatch = useDispatch();
  const history = useHistory();
  const { isAuthenticated }: AuthState = useSelector<AppState, any>(state => state.auth);
  const { clients }: ClientsState = useSelector<AppState, any>(state => state.clients);

  const [filtered, setFiltered] = useState<any[]>([]);

  const addClient = () => {
    history.push('/clients/new');
  }

  // load clients after loading page
  useEffect(() => {
    async function getClients() {
      try {
        dispatch(actions.setLoading(true));
        const clients = await api.getClients();
        dispatch(actions.setClients(clients));
      } catch (error) {
        if (error instanceof NetworkError)
          dispatch(actions.setSnackbar("No teniu connexió a Internet", "error"));
        else if (error instanceof AuthError)
          return history.push("/login");
        else
          dispatch(actions.setErrors(error));
      } finally {
        dispatch(actions.setLoading(false));
      }
    }
    getClients();
  }, [history, dispatch]);

  // set header and page title
  useEffect(() => {
    dispatch(actions.setTitle('Clients'));
  }, [dispatch]);

  return (
    <>
      {isAuthenticated &&
        <>
          <Header />
          <Container maxWidth={false}>
            <Grid container justify="center" spacing={3}>

              <Grid item xs={12}>
                <ClientsListFilter
                  list={sortByNumber(clients)}
                  setFiltered={setFiltered}
                />
              </Grid>

              <Grid item xs={12}>
                <ClientsList
                  clients={filtered}
                />
              </Grid>

              <AddClientButton addClient={addClient} />

            </Grid>
          </Container>
        </>
      }
    </>
  )
}

export default Clients
