import { Container, Grid } from '@material-ui/core';
import React, { useEffect, useState } from 'react';
import { useDispatch, useSelector } from 'react-redux';
import { useHistory } from 'react-router-dom';
import api from '../api';
import { AuthError } from '../classes/AuthError';
import { NetworkError } from '../classes/NetworkError';
import Header from '../components/common/Header';
import AddInvoiceButton from '../components/Invoices/AddInvoiceButton';
import InvoicesList from '../components/Invoices/InvoicesList';
import InvoicesListFilter from '../components/Invoices/InvoicesListFilter';
import actions from '../redux/actions';
import { AppState } from '../redux/reducers';
import { AuthState } from '../redux/reducers/auth';
import { InvoicesState } from '../redux/reducers/invoices';

const Invoices = () => {
  const dispatch = useDispatch();
  const history = useHistory();
  const { isAuthenticated }: AuthState = useSelector<AppState, any>(state => state.auth);
  const { invoices }: InvoicesState = useSelector<AppState, any>(state => state.invoices);

  const [filtered, setFiltered] = useState<any[]>([]);

  const addInvoice = () => {
    history.push('/invoices/new');
  }

  // load invoices after loading page
  useEffect(() => {
    async function getInvoices() {
      try {
        dispatch(actions.setLoading(true));
        const invoices = await api.getInvoices();
        // setFiltered(invoices);
        dispatch(actions.setInvoices(invoices));
        dispatch(actions.setCurrentInvoice({}));
      } catch (error) {
        if (error instanceof NetworkError)
          dispatch(actions.setSnackbar("No teniu connexió a Internet", "error"));
        else if (error instanceof AuthError)
          return history.push("/login");
        else
          dispatch(actions.setErrors(error));
      } finally {
        dispatch(actions.setLoading(false));
      }
    }
    getInvoices();
  }, [history, dispatch]);

  // set header and page title
  useEffect(() => {
    dispatch(actions.setTitle('Factures'));
  }, [dispatch]);

  return (
    <>
      {isAuthenticated &&
        <>
          <Header />
          <Container maxWidth={false}>
            <Grid container justify="center" spacing={3}>

              <Grid item xs={12}>
                <InvoicesListFilter
                  list={invoices}
                  setFiltered={setFiltered}
                />
              </Grid>

              <Grid item xs={12}>
                <InvoicesList
                  invoices={filtered}
                />
              </Grid>

              <AddInvoiceButton addInvoice={addInvoice} />

            </Grid>

          </Container>
        </>
      }
    </>
  )
}

export default Invoices
