import React, { useEffect, useState } from 'react';
import { useDispatch } from 'react-redux';
import { useHistory } from "react-router-dom";
import api from '../api';
import { NetworkError } from '../classes/NetworkError';
import DialogRecoveryEmail from '../components/Login/DialogRecoveryEmail';
import LoginForm from '../components/Login/LoginForm';
import actions from '../redux/actions';

const Login = () => {
  const dispatch = useDispatch();
  const history = useHistory();
  const [data, setData] = useState<any>({});

  const [openRecoveryDialog, setOpenRecoveryDialog] = useState<boolean>(false);

  const sendRecoveryEmail = async () => {
    try {
      dispatch(actions.deleteErrors());
      dispatch(actions.setLoading(true));
      await api.sendRecoveryEmail(data.email);
      setOpenRecoveryDialog(true);
    } catch (error) {
      if (error instanceof NetworkError)
        dispatch(actions.setSnackbar("No teniu connexió a Internet", "error"));
      else
        dispatch(actions.setErrors(error));
    } finally {
      dispatch(actions.setLoading(false));
    }
  }

  const register = () => {
    history.replace('/register');
  }

  const submit = async (e: any) => {
    e.preventDefault();
    try {
      dispatch(actions.deleteErrors());
      dispatch(actions.setLoading(true));
      const token = await api.login(data.email, data.password);
      dispatch(actions.login(token));
      const user = await api.getCurrentUser();
      dispatch(actions.setCurrentUser(user));
      history.push('/invoices');
    } catch (error) {
      if (error instanceof NetworkError) {
        dispatch(actions.setSnackbar("No teniu connexió a Internet", "error"));
      } else {
        dispatch(actions.setErrors(error));
      }
    } finally {
      dispatch(actions.setLoading(false));
    }
  }

  // set header and page title
  useEffect(() => {
    dispatch(actions.setTitle('Entrar'));
  }, [dispatch]);

  return (
    <div>
      <LoginForm
        data={data}
        setData={setData}
        submit={submit}
        sendRecoveryEmail={sendRecoveryEmail}
        register={register}
      />
      <DialogRecoveryEmail
        open={openRecoveryDialog}
        setOpen={setOpenRecoveryDialog}
      />
    </div>
  )
}

export default Login
