import React, { FormEvent, useEffect, useState } from 'react';
import { useDispatch } from 'react-redux';
import { useHistory, useParams } from 'react-router-dom';
import api from '../api';
import { NetworkError } from '../classes/NetworkError';
import PasswordRecoveryForm from '../components/PasswordRecovery/PasswordRecoveryForm';
import actions from '../redux/actions';

const PasswordRecovery = () => {
  const dispatch = useDispatch();
  const history = useHistory();
  const { jwt } = useParams<any>();
  const [data, setData] = useState<any>({});

  const submit = async (e: FormEvent<HTMLFormElement>) => {
    e.preventDefault();
    try {
      dispatch(actions.deleteErrors());
      dispatch(actions.setLoading(true));
      await api.sendRestorePassword(jwt, data);
      dispatch(actions.setSnackbar("La contrasenya ha estat restablerta"))
      history.replace('/login');
    } catch (error) {
      if (error instanceof NetworkError)
        dispatch(actions.setSnackbar("No teniu connexió a Internet", "error"));
      else
        dispatch(actions.setErrors(error));
    } finally {
      dispatch(actions.setLoading(false));
    }
  }

  // set header and page title
  useEffect(() => {
    dispatch(actions.setTitle('Restablir contrasenya'));
  }, [dispatch]);

  return (
    <PasswordRecoveryForm
      data={data}
      setData={setData}
      submit={submit}
    />
  )
}

export default PasswordRecovery
