import { Container } from '@material-ui/core';
import { makeStyles } from '@material-ui/core/styles';
import React, { useEffect, useState } from 'react';
import { useDispatch, useSelector } from 'react-redux';
import { useHistory, useParams } from 'react-router-dom';
import api from '../api';
import { AuthError } from '../classes/AuthError';
import { NetworkError } from '../classes/NetworkError';
import Footer from '../components/Print/Footer';
import Header from '../components/Print/Header';
import '../components/Print/Invoice.css';
import Main from '../components/Print/Main';
import actions from '../redux/actions';
import { AppState } from '../redux/reducers';
import { AuthState } from '../redux/reducers/auth';
import AppHeader from '../components/common/Header';

const useStyles = makeStyles((theme) => ({
  root: {
    backgroundColor: "white",
    marginTop: theme.spacing(4),
    marginBottom: theme.spacing(4),
    width: '42rem',
    height: '60rem',
    lineHeight: '2rem',
    display: 'flex',
    flexDirection: 'column',
  },
}));

const Print = () => {
  const classes = useStyles();
  const history = useHistory();
  const dispatch = useDispatch();
  const { number } = useParams<any>();
  const { token, isAuthenticated }: AuthState = useSelector<AppState, any>(state => state.auth);

  const [invoice, setInvoice] = useState<any>({});
  const [lines, setLines] = useState<any>([]);
  const [client, setClient] = useState<any>({});
  const [emittedInvoice, setEmittedInvoice] = useState<any>(undefined);

  useEffect(() => {
    async function getData() {
      const invoice = await api.getInvoice(number);
      if (invoice.emitted) {
        const emittedInvoice = await api.getEmittedInvoice(number);
        setEmittedInvoice(emittedInvoice);
        setClient(emittedInvoice.client);
      } else {
        const client = await api.getClient(invoice.client);
        setClient(client);
      }
      const lines = await api.getLines(invoice._id);
      setInvoice(invoice);
      setLines(lines);
    }
    getData()
      .catch(error => {
        if (error instanceof NetworkError)
          dispatch(actions.setSnackbar("No teniu connexió a Internet", "error"));
        else if (error instanceof AuthError)
          return history.push("/login");
      });
  }, [number, history, token, dispatch]);

  // set header and page title
  useEffect(() => {
    dispatch(actions.setTitle('Factura ' + number));
  }, [dispatch, number]);

  return (
    <>
      {isAuthenticated &&
        <>
          <AppHeader />
          <Container className={classes.root}>
            <div className="print-header">
              <Header emittedInvoice={emittedInvoice} />
            </div>
            <Main invoice={emittedInvoice || invoice} lines={lines} client={client} />
            <div className="print-footer">
              <Footer emittedInvoice={emittedInvoice} />
            </div>
            {(invoice.cancelled || (emittedInvoice && emittedInvoice.cancelled)) &&
              <div className="print-cancelled-wrapper">
                <div className="print-cancelled">
                  Anul·lada
          </div>
              </div>
            }
          </Container>
        </>
      }
    </>
  )
}

export default Print
