import React, { FormEvent, useEffect, useState } from 'react';
import { useDispatch, useSelector } from 'react-redux';
import { useHistory } from "react-router-dom";
import api from '../api';
import { AuthError } from '../classes/AuthError';
import { NetworkError } from '../classes/NetworkError';
import Header from '../components/common/Header';
import DialogModifyPassword from '../components/Profile/DialogModifyPassword';
import ProfileForm from '../components/Profile/ProfileForm';
import actions from '../redux/actions';
import { AppState } from '../redux/reducers';
import { AuthState } from '../redux/reducers/auth';

const Profile = () => {
  const dispatch = useDispatch();
  const history = useHistory();
  const { user, isAuthenticated }: AuthState = useSelector<AppState, any>(state => state.auth);

  const [data, setData] = useState<any>({});

  const [openPasswordDialog, setOpenPasswordDialog] = useState<boolean>(false);

  const submit = async (e: FormEvent<HTMLFormElement>) => {
    e.preventDefault();
    try {
      dispatch(actions.deleteErrors());
      dispatch(actions.setLoading(true));
      const user = await api.updateUser(data);
      dispatch(actions.setCurrentUser(user));
      history.push('/invoices');
      dispatch(actions.setSnackbar("Les dades s'han desat correctament"))
    } catch (error) {
      if (error instanceof NetworkError)
        dispatch(actions.setSnackbar("No teniu connexió a Internet", "error"));
      else if (error instanceof AuthError)
        return history.push("/login");
      else
        dispatch(actions.setErrors(error));
    } finally {
      dispatch(actions.setLoading(false));
    }
  }

  const cancel = () => {
    history.goBack();
  }

  const setPassword = (password: string, password2: string) => {
    setData({ ...data, password, password2 });
  }

  // load current user
  useEffect(() => {
    if (user) setData(user);
  }, [user]);

  // set header and page title
  useEffect(() => {
    dispatch(actions.setTitle('Perfil'));
  }, [dispatch]);

  return (
    <>
      {isAuthenticated &&
        <>
          <Header />
          <ProfileForm
            data={data}
            setData={setData}
            setOpenPasswordDialog={setOpenPasswordDialog}
            submit={submit}
            cancel={cancel}
          />
          <DialogModifyPassword
            open={openPasswordDialog}
            setOpen={setOpenPasswordDialog}
            changePassword={setPassword}
          />
        </>
      }
    </>
  )
}

export default Profile
