import React, { useEffect, useState } from 'react';
import { useDispatch } from 'react-redux';
import { useHistory } from "react-router-dom";
import api from '../api';
import { NetworkError } from '../classes/NetworkError';
import DialogRegistered from '../components/Register/DialogRegistered';
import RegisterForm from '../components/Register/RegisterForm';
import actions from '../redux/actions';

const Register = () => {
  const dispatch = useDispatch();
  const history = useHistory();

  const [data, setData] = useState<any>({});
  const [openRegisteredDialog, setOpenRegisteredDialog] = useState<boolean>(false);

  const login = () => {
    history.replace('/login');
  }

  const submit = async (e: any) => {
    e.preventDefault();
    try {
      dispatch(actions.deleteErrors());
      dispatch(actions.setLoading(true));
      await api.register(data);
      setOpenRegisteredDialog(true);
    } catch (error) {
      if (error instanceof NetworkError)
        dispatch(actions.setSnackbar("No teniu connexió a Internet", "error"));
      else
        dispatch(actions.setErrors(error));
    } finally {
      dispatch(actions.setLoading(false));
    }
  }

  // set header and page title
  useEffect(() => {
    dispatch(actions.setTitle('Registre'));
  }, [dispatch]);

  return (
    <>
      <RegisterForm
        data={data}
        setData={setData}
        submit={submit}
        login={login}
      />

      <DialogRegistered
        open={openRegisteredDialog}
        setOpen={setOpenRegisteredDialog}
        onClose={login}
      />
    </>
  )
}

export default Register
