import { CLOSE_SNACKBAR, SET_CANCELLING, SET_DELETING, SET_EMITTING, SET_LOADING, SET_LOADING_LINES, SET_SAVING, SET_SNACKBAR, SET_TITLE } from "../actionTypes";

export type UiState = {
  title: string;
  isLoading: boolean;
  isLoadingLines: boolean;
  isSaving: boolean;
  isEmitting: boolean;
  isCancelling: boolean;
  isDeleting: boolean;
  openSnackbar: boolean;
  snackbar: {
    info: string;
    severity: "success" | "info" | "warning" | "error" | undefined;
  };
}

export const initialUi: UiState = {
  title: '',
  isLoading: false,
  isLoadingLines: false,
  isSaving: false,
  isEmitting: false,
  isCancelling: false,
  isDeleting: false,
  openSnackbar: false,
  snackbar: {
    info: "",
    severity: "success"
  },
}

export const ui = (state = initialUi, action: any): UiState => {
  switch (action.type) {
    case SET_TITLE:
      return {
        ...state,
        title: action.payload
      };
    case SET_LOADING:
      return {
        ...state,
        isLoading: action.payload
      }
    case SET_LOADING_LINES:
      return {
        ...state,
        isLoadingLines: action.payload
      }
    case SET_SAVING:
      return {
        ...state,
        isSaving: action.payload
      }
    case SET_EMITTING:
      return {
        ...state,
        isEmitting: action.payload
      }
    case SET_CANCELLING:
      return {
        ...state,
        isCancelling: action.payload
      }
    case SET_DELETING:
      return {
        ...state,
        isDeleting: action.payload
      }
    case CLOSE_SNACKBAR:
      return {
        ...state,
        openSnackbar: false
      }
    case SET_SNACKBAR:
      return {
        ...state,
        openSnackbar: true,
        snackbar: {
          info: action.payload.info,
          severity: action.payload.severity
        }
      }
    default:
      return state;
  }
}